import request from '@/config/axios'

// 预约 VO
export interface AppointmentVO {
  patId: string // 患者编号
  patName: string // 患者姓名
  patGender: boolean // 患者性别
  patBirthday: Date // 患者生日
  patMobile: string // 患者手机
  patPhone: string // 患者电话
  patIdentityId: string // 身份证号
  patAddr: string // 患者地址
  patDeptCode: string // 患者所在科室代码
  patDeptDesc: string // 患者所在科室名称
  patWardCode: string // 患者所在病区代码
  patWardDesc: string // 患者所在病区名称
  patBedNo: string // 床号
  bookId: string // 预约编号
  bookPeriodStart: Date // 预约检查时间段
  bookPeriodEnd: Date // 预约检查时间段
  bookTime: Date // 预约发生时间
  bookCheckType: boolean // 预约检查类型
}

// 预约 API
export const AppointmentApi = {
  // 查询预约分页
  getAppointmentPage: async (params: any) => {
    return await request.get({ url: `/ecg/appointment/page`, params })
  },

  // 查询预约详情
  getAppointment: async (id: number) => {
    return await request.get({ url: `/ecg/appointment/get?id=` + id })
  },

  // 新增预约
  createAppointment: async (data: AppointmentVO) => {
    return await request.post({ url: `/ecg/appointment/create`, data })
  },

  // 修改预约
  updateAppointment: async (data: AppointmentVO) => {
    return await request.put({ url: `/ecg/appointment/update`, data })
  },

  // 删除预约
  deleteAppointment: async (id: number) => {
    return await request.delete({ url: `/ecg/appointment/delete?id=` + id })
  },

  // 导出预约 Excel
  exportAppointment: async (params) => {
    return await request.download({ url: `/ecg/appointment/export-excel`, params })
  }
}